Test coverage report: frequently.cms_app

# frequently.cms_app: 7 total statements, 0.0% covered

Generated: Fri 2013-04-26 21:01 CEST

Source file: /home/tobi/Projects/django-frequently/src/frequently/cms_app.py

Stats: 0 executed, 4 missed, 3 excluded, 8 ignored

1. `"""`
2. `django-cms Apphook for the ``django-frequently`` application.`
3. ``
4. `"""`
5. `from cms.app_base import CMSApp`
6. `from cms.apphook_pool import apphook_pool`
7. `from django.utils.translation import ugettext_lazy as _`
8. ``
9. ``
10. `class FrequentlyApphook(CMSApp):`
11. `name = _("Frequently App")`
12. `urls = ["frequently.urls"]`
13. ``
14. ``
15. `apphook_pool.register(FrequentlyApphook)`